@@ -2,7 +2,7 @@
 #######################################################################
 """Product class for the Zope 3 based quota package
 
-$Id: handle.py 51043 2008-04-29 02:23:07Z cray $
+$Id: handle.py 52853 2009-04-07 13:06:12Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
@@ -16,10 +16,14 @@ def handleAdded(ob,event) :
         quota.handleAdded(ob)
 
 def handleModified(ob,event) :
-    for quota in IQuotaAll(ob) :
-        quota.handleModified(ob)
+    try :
+        for quota in IQuotaAll(ob) :
+            quota.handleModified(ob)
+    except AttributeError,msg :
+        print "QuotaError 2:",msg
 
 def handleRemoved(ob,event) :
     for quota in IQuotaAll(ob) :
         quota.handleRemoved(ob)
+
                
\ No newline at end of file
